@@ -94,25 +94,22 @@ class gram():
         return self.value
 
     def __add__(self, other):
-        return gram(f"{self.value}+{other.rule()}")
+        return gram(f"({self.value})+({other.rule()})")
 
     def __mul__(self, other):
         return gram(f"{self.value}*{other.rule()}")
 
     def __lt__(self, other):
-        return gram(f"{self.value}/{other.rule()}")
+        return gram(f"({self.value})/({other.rule()})")
 
     def __gt__(self, other):
-        return gram(f"{self.value}\\{other.rule()}")
-
-    def __lt__(self, other):
-        return gram(f"{self.value}/{other.rule()}")
+        return gram(f"({self.value})\\({other.rule()})")
 
     def __or__(self, other):
         if not self.value.startswith("|"):
-            return gram(f"|{self.value}, |{other.rule()}")
+            return gram(f"|({self.value}), |({other.rule()})")
         else:
-            return gram(f"{self.value}, |{other.rule()}")
+            return gram(f"{self.value}, |({other.rule()})")
 
     def __getitem__(self, key):
         rule = key.rule()
